package dev.fitko.fitconnect.api.services.destination;

import com.nimbusds.jose.jwk.RSAKey;
import dev.fitko.fitconnect.api.domain.model.destination.Destination;
import dev.fitko.fitconnect.api.services.validation.ValidationService;

import java.util.UUID;

/**
 * Service to retrieve and validate public keys from a {@link Destination} or the submission service well-known keys.
 *
 * @see dev.fitko.fitconnect.api.services.portal.SelfServicePortalService
 * @see ValidationService
 *
 */
public interface KeyService {

    /**
     * Get the public encryption key for a given destination.
     *
     * @param destinationId unique identifier of the {@link Destination}
     *
     * @return validated {@link RSAKey} (@see {@link ValidationService#validatePublicKey(RSAKey)})
     */
    RSAKey getPublicEncryptionKey(UUID destinationId);

    /**
     * Get the public signature key for a given destination.
     *
     * @param destinationId unique identifier of the {@link Destination}
     * @param keyId unique identifier of the {@link RSAKey}
     * @return validated {@link RSAKey} (@see {@link ValidationService#validatePublicKey(RSAKey)})
     */
    RSAKey getPublicSignatureKey(UUID destinationId, String keyId);

    /**
     * Get the public signature key of the submission service for a given signature key-id.
     *
     * @param keyId unique identifier of the {@link RSAKey}
     * @return validated {@link RSAKey} (@see {@link ValidationService#validatePublicKey(RSAKey)})
     */
    RSAKey getPortalSignatureKey(String keyId);
}
